# Interoperability

Interoperability with other in-memory Python

::: geoarrow.rust.core
    options:
      filters:
        - "!^_"
      members:
        - from_ewkb
        - from_geopandas
        - from_shapely
        - from_wkb
        - from_wkt
        - to_geopandas
        - to_shapely
        - to_wkb
